@@ -76,11 +76,11 @@ class MTRand {
 public:
 	typedef unsigned long uint32;  // unsigned integer type, at least 32 bits
 	
-	enum { N = 624 };       // length of state vector
-	enum { SAVE = N + 1 };  // length of array for save()
+	static const uint32 N = 624;       // length of state vector
+	static const uint32 SAVE = N + 1;  // length of array for save()
 
 protected:
-	enum { M = 397 };  // period parameter
+	static const uint32 M = 397;  // period parameter
 	
 	uint32 state[N];   // internal state
 	uint32 *pNext;     // next value to get from state
@@ -98,6 +98,10 @@ public:
 	// reading 624 consecutive values.
 	
 	// Access to 32-bit random numbers
+	template<typename FloatT>
+	FloatT rand();                          // real number in [0,1]
+	float randf();                          // real number in [0,1]
+	float randf( const float& n );          // real number in [0,n]
 	double rand();                          // real number in [0,1]
 	double rand( const double& n );         // real number in [0,n]
 	double randExc();                       // real number in [0,1)
@@ -149,6 +153,20 @@ inline MTRand::MTRand( uint32 *const bigSeed, const uint32 seedLength ) : pNext(
 inline MTRand::MTRand() : pNext(0), left(0)
 	{ seed(); }
 
+template<>
+inline float MTRand::rand<float>()
+	{ return float(randInt()) * (1.0f/4294967295.0f); }
+
+template<>
+inline double MTRand::rand<double>()
+	{ return double(randInt()) * (1.0/4294967295.0); }
+
+inline float MTRand::randf()
+	{ return float(randInt()) * (1.0f/4294967295.0f); }
+
+inline float MTRand::randf( const float& n )
+	{ return randf() * n; }
+
 inline double MTRand::rand()
 	{ return double(randInt()) * (1.0/4294967295.0); }
 
@@ -177,9 +195,9 @@ inline double MTRand::randNorm( const double& mean, const double& variance )
 {
 	// Return a real number from a normal (Gaussian) distribution with given
 	// mean and variance by Box-Muller method
-	double r = sqrt( -2.0 * log( 1.0-randDblExc()) ) * variance;
+	double r = std::sqrt( -2.0 * std::log( 1.0-randDblExc()) ) * variance;
 	double phi = 2.0 * 3.14159265358979323846264338328 * randExc();
-	return mean + r * cos(phi);
+	return mean + r * std::cos(phi);
 }
 
 inline MTRand::uint32 MTRand::randInt()
@@ -235,9 +253,9 @@ inline void MTRand::seed( uint32 *const bigSeed, const uint32 seedLength )
 	// in each element are discarded.
 	// Just call seed() if you want to get array from /dev/urandom
 	initialize(19650218UL);
-	register int i = 1;
+	register unsigned i = 1;
 	register uint32 j = 0;
-	register int k = ( N > seedLength ? N : seedLength );
+	register unsigned k = ( N > seedLength ? N : seedLength );
 	for( ; k; --k )
 	{
 		state[i] =
@@ -270,7 +288,7 @@ inline void MTRand::initialize( const uint32 seed )
 	// only MSBs of the state array.  Modified 9 Jan 2002 by Makoto Matsumoto.
 	register uint32 *s = state;
 	register uint32 *r = state;
-	register int i = 1;
+	register unsigned i = 1;
 	*s++ = seed & 0xffffffffUL;
 	for( ; i < N; ++i )
 	{
