@@ -84,7 +84,7 @@ class AxisBox
   AxisBox& operator=(const AxisBox& a)
   {m_low = a.m_low; m_high = a.m_high; return *this;}
 
-  bool isEqualTo(const AxisBox& b, double epsilon = WFMATH_EPSILON) const;
+  bool isEqualTo(const AxisBox& b, CoordType epsilon = numeric_constants<CoordType>::epsilon()) const;
   bool operator==(const AxisBox& a) const	{return isEqualTo(a);}
   bool operator!=(const AxisBox& a) const	{return !isEqualTo(a);}
 
@@ -92,8 +92,8 @@ class AxisBox
 
   // Descriptive characteristics
 
-  int numCorners() const {return 1 << dim;}
-  Point<dim> getCorner(int i) const;
+  size_t numCorners() const {return 1 << dim;}
+  Point<dim> getCorner(size_t i) const;
   Point<dim> getCenter() const {return Midpoint(m_low, m_high);}
 
   /// Get a reference to corner 0
@@ -121,7 +121,7 @@ class AxisBox
 
   AxisBox& shift(const Vector<dim>& v)
   {m_low += v; m_high += v; return *this;}
-  AxisBox& moveCornerTo(const Point<dim>& p, int corner)
+  AxisBox& moveCornerTo(const Point<dim>& p, size_t corner)
   {return shift(p - getCorner(corner));}
   AxisBox& moveCenterTo(const Point<dim>& p)
   {return shift(p - getCenter());}
@@ -179,6 +179,13 @@ class AxisBox
   Point<dim> m_low, m_high;
 };
 
+template<int dim>
+inline bool AxisBox<dim>::isEqualTo(const AxisBox<dim>& b, CoordType epsilon) const
+{
+  return Equal(m_low, b.m_low, epsilon)
+       && Equal(m_high, b.m_high, epsilon);
+}
+
 } // namespace WFMath
 
 #endif  // WFMATH_AXIS_BOX_H
