@@ -29,7 +29,7 @@
 
 #include <cassert>
 
-using namespace WFMath;
+namespace WFMath {
 
 // force a bunch of instantiations
 
@@ -120,9 +120,6 @@ template bool Intersect<AxisBox<2>,RotBox<2> >(const AxisBox<2>&, const RotBox<2
 template bool Intersect<AxisBox<3>,RotBox<3> >(const AxisBox<3>&, const RotBox<3>&, bool);
 template bool Contains<2>(const AxisBox<2>&, const RotBox<2>&, bool);
 template bool Contains<3>(const AxisBox<3>&, const RotBox<3>&, bool);
-// don't need these two declared, they're already specializations
-//template bool Intersect<2>(const RotBox<2>&, const AxisBox<2>&, bool);
-//template bool Intersect<3>(const RotBox<3>&, const AxisBox<3>&, bool);
 template bool Contains<2>(const RotBox<2>&, const AxisBox<2>&, bool);
 template bool Contains<3>(const RotBox<3>&, const AxisBox<3>&, bool);
 
@@ -182,7 +179,7 @@ template bool Contains<3>(const RotBox<3>&, const RotBox<3>&, bool);
 // this line separates b from B(a), and they do not intersect. QED.
 
 template<>
-bool WFMath::Intersect<2>(const RotBox<2>& r, const AxisBox<2>& b, bool proper)
+bool Intersect<2>(const RotBox<2>& r, const AxisBox<2>& b, bool proper)
 {
   const AxisBox<2> b2 = r.boundingBox();
   if(!Intersect(b2, b, proper))
@@ -227,7 +224,7 @@ bool WFMath::Intersect<2>(const RotBox<2>& r, const AxisBox<2>& b, bool proper)
 // 1996
 
 template<>
-bool WFMath::Intersect<3>(const RotBox<3>& r, const AxisBox<3>& b, bool proper)
+bool Intersect<3>(const RotBox<3>& r, const AxisBox<3>& b, bool proper)
 {
   // Checking intersection of each with the bounding box of
   // the other in the coordinate system of the first will take care
@@ -283,7 +280,7 @@ bool WFMath::Intersect<3>(const RotBox<3>& r, const AxisBox<3>& b, bool proper)
           assert(false);
       }
 
-      if(axis.sqrMag() < WFMATH_EPSILON * WFMATH_EPSILON) {
+      if(axis.sqrMag() < numeric_constants<CoordType>::epsilon() * numeric_constants<CoordType>::epsilon()) {
         // Parallel edges, this reduces to the 2d case above. We've already
         // checked the bounding box intersections, so we know they intersect.
         // We don't need to scale WFMATH_EPSILON, det(m_orient) = 1
@@ -361,3 +358,5 @@ bool WFMath::Intersect<3>(const RotBox<3>& r, const AxisBox<3>& b, bool proper)
 
   return true;
 }
+
+}
