@@ -24,25 +24,26 @@
 // Created: 2002-1-4
 
 #include "polygon_funcs.h"
+#include "rotbox.h"
 
 namespace WFMath {
 
-void _Poly2Reorient::reorient(Polygon<2>& poly, int skip) const
+void _Poly2Reorient::reorient(Polygon<2>& poly, size_t skip) const
 {
-  int end = poly.numCorners();
+  size_t end = poly.numCorners();
 
   switch(m_type) {
     case _WFMATH_POLY2REORIENT_NONE:
       return;
     case _WFMATH_POLY2REORIENT_CLEAR_AXIS2:
-      for(int i = 0; i != end; ++i) {
+      for(size_t i = 0; i != end; ++i) {
         if(i == skip)
           continue;
         (poly[i])[1] = 0;
       }
       return;
     case _WFMATH_POLY2REORIENT_CLEAR_BOTH_AXES:
-      for(int i = 0; i != end; ++i) {
+      for(size_t i = 0; i != end; ++i) {
         if(i == skip)
           continue;
         (poly[i])[0] = 0;
@@ -50,7 +51,7 @@ void _Poly2Reorient::reorient(Polygon<2>& poly, int skip) const
       }
       return;
     case _WFMATH_POLY2REORIENT_MOVE_AXIS2_TO_AXIS1:
-      for(int i = 0; i != end; ++i) {
+      for(size_t i = 0; i != end; ++i) {
         if(i == skip)
            continue;
         (poly[i])[0] = (poly[i])[1];
@@ -58,7 +59,7 @@ void _Poly2Reorient::reorient(Polygon<2>& poly, int skip) const
       }
       return;
     case _WFMATH_POLY2REORIENT_SCALE1_CLEAR2:
-      for(int i = 0; i != end; ++i) {
+      for(size_t i = 0; i != end; ++i) {
         if(i == skip)
           continue;
         (poly[i])[0] *= m_scale;
@@ -72,7 +73,7 @@ void _Poly2Reorient::reorient(Polygon<2>& poly, int skip) const
 }
 
 //template<>
-bool Polygon<2>::isEqualTo(const Polygon<2>& p, double epsilon) const
+bool Polygon<2>::isEqualTo(const Polygon<2>& p, CoordType epsilon) const
 {
   if(m_points.size() != p.m_points.size())
     return false;
