@@ -26,13 +26,10 @@
 #ifndef WFMATH_POLYGON_H
 #define WFMATH_POLYGON_H
 
+#include <wfmath/const.h>
 #include <wfmath/axisbox.h>
 #include <wfmath/ball.h>
-#include <wfmath/vector.h>
-#include <wfmath/point.h>
 #include <wfmath/quaternion.h>
-#include <wfmath/rotbox.h>
-#include <wfmath/intersect_decls.h>
 
 #include <vector>
 
@@ -69,7 +66,7 @@ class Polygon<2>
   Polygon& operator=(const Polygon& p)
   {m_points = p.m_points; return *this;}
 
-  bool isEqualTo(const Polygon& p, double epsilon = WFMATH_EPSILON) const;
+  bool isEqualTo(const Polygon& p, CoordType epsilon = numeric_constants<CoordType>::epsilon()) const;
 
   bool operator==(const Polygon& p) const	{return isEqualTo(p);}
   bool operator!=(const Polygon& p) const	{return !isEqualTo(p);}
@@ -78,8 +75,8 @@ class Polygon<2>
 
   // Descriptive characteristics
 
-  int numCorners() const {return m_points.size();}
-  Point<2> getCorner(int i) const {return m_points[i];}
+  size_t numCorners() const {return m_points.size();}
+  Point<2> getCorner(size_t i) const {return m_points[i];}
   Point<2> getCenter() const {return Barycenter(m_points);}
 
   // For a Polygon<2>, addCorner() and moveCorner() always succeed.
@@ -87,33 +84,33 @@ class Polygon<2>
   // interface, and the epsilon argument is ignored
 
   // Add before i'th corner, zero is beginning, numCorners() is end
-  bool addCorner(int i, const Point<2>& p, double epsilon = WFMATH_EPSILON)
+  bool addCorner(size_t i, const Point<2>& p, CoordType = numeric_constants<CoordType>::epsilon())
   {m_points.insert(m_points.begin() + i, p); return true;}
 
   // Remove the i'th corner
-  void removeCorner(int i) {m_points.erase(m_points.begin() + i);}
+  void removeCorner(size_t i) {m_points.erase(m_points.begin() + i);}
 
   // Move the i'th corner to p
-  bool moveCorner(int i, const Point<2>& p, double epsilon = WFMATH_EPSILON)
+  bool moveCorner(size_t i, const Point<2>& p, CoordType = numeric_constants<CoordType>::epsilon())
   {m_points[i] = p; return true;}
 
   // Remove all points
   void clear()	{m_points.clear();}
 
-  const Point<2>& operator[](int i) const {return m_points[i];}
-  Point<2>& operator[](int i)		  {return m_points[i];}
+  const Point<2>& operator[](size_t i) const {return m_points[i];}
+  Point<2>& operator[](size_t i)		  {return m_points[i];}
 
-  void resize(unsigned int size) {m_points.resize(size);}
+  void resize(std::vector<Point<2> >::size_type size) {m_points.resize(size);}
 
   // Movement functions
 
   Polygon& shift(const Vector<2>& v);
-  Polygon& moveCornerTo(const Point<2>& p, int corner)
+  Polygon& moveCornerTo(const Point<2>& p, size_t corner)
   {return shift(p - getCorner(corner));}
   Polygon& moveCenterTo(const Point<2>& p)
   {return shift(p - getCenter());}
 
-  Polygon& rotateCorner(const RotMatrix<2>& m, int corner)
+  Polygon& rotateCorner(const RotMatrix<2>& m, size_t corner)
   {rotatePoint(m, getCorner(corner)); return *this;}
   Polygon& rotateCenter(const RotMatrix<2>& m)
   {rotatePoint(m, getCenter()); return *this;}
@@ -188,7 +185,7 @@ public:
   : m_type(type), m_scale(scale) {}
   ~_Poly2Reorient() {}
 
-  void reorient(Polygon<2>& poly, int skip = -1) const;
+  void reorient(Polygon<2>& poly, size_t skip = std::numeric_limits<size_t>::max()) const;
 
 private:
   _Poly2ReorientType m_type;
@@ -229,12 +226,12 @@ public:
   // Try to convert a point from dim dimensions into 2D, expanding the
   // basis if necessary. Returns true on success. On failure, the
   // basis is unchanged.
-  bool expand(const Point<dim>& pd, Point<2>& p2, double epsilon = WFMATH_EPSILON);
+  bool expand(const Point<dim>& pd, Point<2>& p2, CoordType epsilon = numeric_constants<CoordType>::epsilon());
 
   // Reduce the basis to the minimum necessary to span the points in
   // poly (with the exception of skip). Returns _Poly2Reorient, which needs
   // to be used to reorient the points to match the new basis.
-  _Poly2Reorient reduce(const Polygon<2>& poly, int skip = -1);
+  _Poly2Reorient reduce(const Polygon<2>& poly, size_t skip = std::numeric_limits<size_t>::max());
 
   void shift(const Vector<dim>& v) {if(m_origin.isValid()) m_origin += v;}
   void rotate(const RotMatrix<dim>& m, const Point<dim>& p);
@@ -320,7 +317,7 @@ public:
   Polygon& operator=(const Polygon& p)
   {m_orient = p.m_orient; m_poly = p.m_poly; return *this;}
 
-  bool isEqualTo(const Polygon& p2, double epsilon = WFMATH_EPSILON) const;
+  bool isEqualTo(const Polygon& p2, CoordType epsilon = numeric_constants<CoordType>::epsilon()) const;
 
   bool operator==(const Polygon& p) const	{return isEqualTo(p);}
   bool operator!=(const Polygon& p) const	{return !isEqualTo(p);}
@@ -329,8 +326,8 @@ public:
 
   // Descriptive characteristics
 
-  int numCorners() const {return m_poly.numCorners();}
-  Point<dim> getCorner(int i) const {return m_orient.convert(m_poly[i]);}
+  size_t numCorners() const {return m_poly.numCorners();}
+  Point<dim> getCorner(size_t i) const {return m_orient.convert(m_poly[i]);}
   Point<dim> getCenter() const {return m_orient.convert(m_poly.getCenter());}
 
   // The failure of the following functions does not invalidate the
@@ -338,16 +335,16 @@ public:
 
   // Add before i'th corner, zero is beginning, numCorners() is end
   // Only succeeds if p lies in a plane with all current points
-  bool addCorner(int i, const Point<dim>& p, double epsilon = WFMATH_EPSILON);
+  bool addCorner(size_t i, const Point<dim>& p, CoordType epsilon = numeric_constants<CoordType>::epsilon());
 
   // Remove the i'th corner
-  void removeCorner(int i);
+  void removeCorner(size_t i);
 
   // Move the i'th corner to p, only succeeds if new location
   // lies in the same plane as all the other points. Note that,
   // under certain circumstances, this plane may not contain the
   // original location of the point.
-  bool moveCorner(int i, const Point<dim>& p, double epsilon = WFMATH_EPSILON);
+  bool moveCorner(size_t i, const Point<dim>& p, CoordType epsilon = numeric_constants<CoordType>::epsilon());
 
   // Remove all points
   void clear()	{m_poly.clear(); m_orient = _Poly2Orient<dim>();}
@@ -356,12 +353,12 @@ public:
 
   Polygon& shift(const Vector<dim>& v)
   {m_orient.shift(v); return *this;}
-  Polygon& moveCornerTo(const Point<dim>& p, int corner)
+  Polygon& moveCornerTo(const Point<dim>& p, size_t corner)
   {return shift(p - getCorner(corner));}
   Polygon& moveCenterTo(const Point<dim>& p)
   {return shift(p - getCenter());}
 
-  Polygon& rotateCorner(const RotMatrix<dim>& m, int corner)
+  Polygon& rotateCorner(const RotMatrix<dim>& m, size_t corner)
   {m_orient.rotate2(m, m_poly[corner]); return *this;}
   Polygon& rotateCenter(const RotMatrix<dim>& m)
   {if(m_poly.numCorners() > 0)
@@ -371,7 +368,7 @@ public:
   {m_orient.rotate(m, p); return *this;}
 
   // 3D rotation functions
-  Polygon<3>& rotateCorner(const Quaternion& q, int corner)
+  Polygon<3>& rotateCorner(const Quaternion& q, size_t corner)
   {m_orient.rotate2(q, m_poly[corner]); return *this;}
   Polygon<3>& rotateCenter(const Quaternion& q)
   {if(m_poly.numCorners() > 0)
@@ -440,6 +437,41 @@ public:
   Polygon<2> m_poly;
 };
 
+template<int dim>
+inline bool Polygon<dim>::addCorner(size_t i, const Point<dim>& p, CoordType epsilon)
+{
+  Point<2> p2;
+  bool succ = m_orient.expand(p, p2, epsilon);
+  if(succ)
+    m_poly.addCorner(i, p2, epsilon);
+  return succ;
+}
+
+template<int dim>
+inline void Polygon<dim>::removeCorner(size_t i)
+{
+  m_poly.removeCorner(i);
+  _Poly2Reorient r = m_orient.reduce(m_poly);
+  r.reorient(m_poly);
+}
+
+template<int dim>
+inline bool Polygon<dim>::moveCorner(size_t i, const Point<dim>& p, CoordType epsilon)
+{
+  _Poly2Orient<dim> try_orient = m_orient;
+  _Poly2Reorient r = try_orient.reduce(m_poly, i);
+  Point<2> p2;
+
+  if(!try_orient.expand(p, p2, epsilon))
+    return false;
+
+  r.reorient(m_poly, i);
+  m_poly[i] = p2;
+  m_orient = try_orient;
+
+  return true;
+}
+
 } // namespace WFMath
 
 #endif  // WFMATH_POLYGON_H
