@@ -75,7 +75,7 @@ class RotBox
 
   RotBox& operator=(const RotBox& s);
 
-  bool isEqualTo(const RotBox& b, double epsilon = WFMATH_EPSILON) const;
+  bool isEqualTo(const RotBox& b, CoordType epsilon = numeric_constants<CoordType>::epsilon()) const;
 
   bool operator==(const RotBox& b) const	{return isEqualTo(b);}
   bool operator!=(const RotBox& b) const	{return !isEqualTo(b);}
@@ -85,8 +85,8 @@ class RotBox
 
   // Descriptive characteristics
 
-  int numCorners() const {return 1 << dim;}
-  Point<dim> getCorner(int i) const;
+  size_t numCorners() const {return 1 << dim;}
+  Point<dim> getCorner(size_t i) const;
   Point<dim> getCenter() const {return m_corner0 + Prod(m_size / 2, m_orient);}
 
   /// returns the base corner of the box
@@ -106,12 +106,12 @@ class RotBox
 
   RotBox& shift(const Vector<dim>& v)
   {m_corner0 += v; return *this;}
-  RotBox& moveCornerTo(const Point<dim>& p, int corner)
+  RotBox& moveCornerTo(const Point<dim>& p, size_t corner)
   {return shift(p - getCorner(corner));}
   RotBox& moveCenterTo(const Point<dim>& p)
   {return shift(p - getCenter());}
 
-  RotBox& rotateCorner(const RotMatrix<dim>& m, int corner)
+  RotBox& rotateCorner(const RotMatrix<dim>& m, size_t corner)
   {rotatePoint(m, getCorner(corner)); return *this;}
   RotBox& rotateCenter(const RotMatrix<dim>& m)
   {rotatePoint(m, getCenter()); return *this;}
@@ -119,7 +119,7 @@ class RotBox
   {m_orient = Prod(m_orient, m); m_corner0.rotate(m, p); return *this;}
 
   // 3D rotation functions
-  RotBox& rotateCorner(const Quaternion& q, int corner);
+  RotBox& rotateCorner(const Quaternion& q, size_t corner);
   RotBox& rotateCenter(const Quaternion& q);
   RotBox& rotatePoint(const Quaternion& q, const Point<dim>& p);
 
@@ -188,6 +188,24 @@ class RotBox
   RotMatrix<dim> m_orient;
 };
 
+template<int dim>
+inline RotBox<dim>& RotBox<dim>::operator=(const RotBox<dim>& a)
+{
+  m_corner0 = a.m_corner0;
+  m_size = a.m_size;
+  m_orient = a.m_orient;
+
+  return *this;
+}
+
+template<int dim>
+inline bool RotBox<dim>::isEqualTo(const RotBox<dim>& b, CoordType epsilon) const
+{
+  return Equal(m_corner0, b.m_corner0, epsilon)
+      && Equal(m_size, b.m_size, epsilon)
+      && Equal(m_orient, b.m_orient, epsilon);
+}
+
 } // namespace WFMath
 
 #endif  // WFMATH_ROT_BOX_H
